@@ -107,7 +107,7 @@ class DialerBackend(BaseBackend):
         raise NotImplementedError('Check dialer state is not supported with the backend')
 
 
-def send_template(recipient, slug, context_data, related_objects=None, tag=None):
+def send_template(recipient, slug, context_data, related_objects=None, tag=None, send_immediately=False):
     """
     Helper for building and sending dialer message from a template.
     :param recipient: phone number of the recipient
@@ -116,6 +116,7 @@ def send_template(recipient, slug, context_data, related_objects=None, tag=None)
     :param related_objects: list of related objects that will be linked with the dialer message using generic
         relation
     :param tag: string mark that will be saved with the message
+    :param send_immediately: publishes the message regardless of the `is_turned_on_batch_sending` result
     :return: dialer message object or None if template cannot be sent
     """
     return _send_template(
@@ -125,10 +126,11 @@ def send_template(recipient, slug, context_data, related_objects=None, tag=None)
         related_objects,
         tag,
         template_model=get_dialer_template_model(),
+        send_immediately=send_immediately
     )
 
 
-def send(recipient, content, related_objects=None, tag=None, **kwargs):
+def send(recipient, content, related_objects=None, tag=None, send_immediately=False, **kwargs):
     """
     Helper for sending dialer message.
     :param recipient: phone number of the recipient
@@ -136,6 +138,7 @@ def send(recipient, content, related_objects=None, tag=None, **kwargs):
     :param related_objects:
     :param tag: string mark that will be saved with the message
     :param kwargs: extra attributes that will be stored with messages
+    :param send_immediately: publishes the message regardless of the `is_turned_on_batch_sending` result
     :return: True if dialer was successfully sent or False if message is in error state
     """
     return _send(
@@ -144,5 +147,6 @@ def send(recipient, content, related_objects=None, tag=None, **kwargs):
         related_objects,
         tag,
         message_controller=DialerController(),
+        send_immediately=send_immediately,
         **kwargs
     )
